autowisp.database.data_model.configuration module — AutoWISP documentation

# autowisp.database.data_model.configuration module

## Class Inheritance Diagram

Define the ProcessingConfiguration table for the pipeline

class autowisp.database.data_model.configuration.Configuration(**kwargs)

  Bases: `DataModelBase`

  Table recording the values of the pipeline configuration parameters.

  condition_expressions
  condition_id

    The id of the condition that must be met for this configuration to apply

  conditions: Mapped[List[Condition]]
  id

    A unique identifier for each row.

  notes

    Any user supplied notes describing the configuration.

  parameter
  parameter_id

    The name of the configuration parameter.

  timestamp

    When record was last changed

  value

    The value of the configuration parameter for the given version for images satisfying the given conditions.

  version

    The version of the configuration parameter. Later versions fall back on earlier versions if an entry for the parameter is not found.